# Reference

## ImageMetadata

::: cgmetadata.ImageMetadata
    handler.: python

## VideoMetadata

::: cgmetadata.VideoMetadata
    handler.: python

## metadata_dictionary_from_xmp_packet

::: cgmetadata.metadata_dictionary_from_xmp_packet
    handler.: python
